@@ -15,15 +15,15 @@ def _define_gestalts():
 
 def alex_rules():
     if time.between("8:00", "17:45") and location.near("Uni"):
-        require(profile, "silent")
+        vote(profile, "silent")
     if location.near("Uni"):
-        require(wifi, "eduroam")
+        vote(wifi, "eduroam")
     #if moving:
     #    vote(secure, on)
     #else:
     #    vote(secure, off)
     if not_moving_for_5min:
-         vote(availability, "away")
+         vote(availability, "away", 2)
          vote(availability_message, "Mobile phone lying still somewhere.")
     if time.between("1:00", "8:00") and location.near("Home"):
         require("Sleeping")
